/*
 * COPYRIGHT INFORMATION - DO NOT REMOVE
 * "Portions Copyright (c) 2000-2001 LinuxMagic Inc. All Rights Reserved.
 *
 * This file contains Original Code and/or Modifications of Original Code as
 * defined in and that are subject to the Free Source Code License Version
 * 1.0 (the 'License'). You may not use this file except in compliance with
 * the License. Please obtain a copy of the License at:
 *
 * http://www.linuxmagic.com/opensource/licensing/
 *
 * and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND LINUXMAGIC HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY, FITNESS
 * FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT. Please see
 * the License for the specific language governing rights and limitations
 * under the License."
 *
 * Please read the terms of this license carefully. By using or downloading
 * this software or file, you are accepting and agreeing to the terms of this
 * license with LinuxMagic Inc. If you are agreeing to this license on behalf
 * of a company, you represent that you are authorized to bind the company to
 * such a license. If you do not meet this criterion or you do not agree to
 * any of the terms of this license, do NOT download, distribute, use or alter
 * this software or file in any way.
 *
 * Author: Burton Samograd (burton@wizard.ca)
 * CVS Id: $Id: auth.c,v 1.24 2002/12/20 19:07:34 burton Exp $
 *
 * DO NOT MODIFY WITHOUT CONSULTING THE LICENSE
 */

/* C includes */
#include <liblm.h>

#include "auth.h"
#include "config_msd.h"

/* Global pointers for driver functions */
static int (*_msd_auth_init)(void);
static int (*_msd_auth_cleanup)(void);
static int (*_msd_do_auth)(int type, lm_string_t username);

int msd_auth_init(void)
{
  if(config.compat_type == MSD_COMPAT_QMAIL)
    {
      _msd_auth_init = msd_auth_init_chkp;
      _msd_auth_cleanup = msd_auth_cleanup_chkp;
      _msd_do_auth = msd_do_auth_chkp;
    }
  else if(config.compat_type != MSD_COMPAT_QMAIL)
    {
      _msd_auth_init = msd_auth_init_db;
      _msd_auth_cleanup = msd_auth_cleanup_db;
      _msd_do_auth = msd_do_auth_db;
    }
  else
    return -1;

  /* Don't call real init function until an auth is requested */
  return 0;
}

int msd_auth_cleanup(void)
{
  int retval;
  
  LM_ASSERT(_msd_auth_cleanup != NULL);
  retval = _msd_auth_cleanup();
  _msd_auth_init = NULL;
  _msd_auth_cleanup = NULL;
  _msd_do_auth = NULL;

  return retval;
}

int msd_do_auth(int type, lm_string_t username64)
{
  LM_ASSERT(_msd_do_auth != NULL);
  return _msd_do_auth(type, username64);
}


